@@ -1,6 +1,6 @@
 
 /* GnomeMeeting -- A Video-Conferencing application
- * Copyright (C) 2000-2003 Damien Sandras
+ * Copyright (C) 2000-2004 Damien Sandras
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -30,7 +30,7 @@
  *                         menu.cpp  -  description 
  *                         ------------------------
  *   begin                : Tue Dec 23 2000
- *   copyright            : (C) 2000-2003 by Damien Sandras
+ *   copyright            : (C) 2000-2004 by Damien Sandras
  *   description          : Functions to create the menus.
  *
  */
@@ -46,8 +46,10 @@
 #include "misc.h"
 #include "chat_window.h"
 #include "ldap_window.h"
+
 #include "stock-icons.h"
 #include "gtk_menu_extensions.h"
+#include "gconf_widgets_extensions.h"
 
 
 /* Declarations */
@@ -86,13 +88,9 @@ static void
 zoom_changed_callback (GtkWidget *widget,
 		       gpointer data)
 {
-  GConfClient *client = NULL;
   double zoom = 0.0;
   
-  client = gconf_client_get_default ();
-  zoom = 
-    gconf_client_get_float (client, VIDEO_DISPLAY_KEY "zoom_factor", NULL);
-
+  zoom = gconf_get_float (VIDEO_DISPLAY_KEY "zoom_factor");
 
   switch (GPOINTER_TO_INT (data)) {
 
@@ -110,27 +108,20 @@ zoom_changed_callback (GtkWidget *widget,
       zoom = zoom * 2.0;
   }
 
-  gconf_client_set_float (client, VIDEO_DISPLAY_KEY "zoom_factor", zoom, NULL);
+  gconf_set_float (VIDEO_DISPLAY_KEY "zoom_factor", zoom);
 }
 
 
 /* DESCRIPTION  :  This callback is called when the user toggles fullscreen
  *                 factor in the popup menu.
  * BEHAVIOR     :  Toggles fullscreen.
- * PRE          :  gpointer is a valid pointer to a GmWindow structure.
+ * PRE          :  / 
  */
 static void 
 fullscreen_changed_callback (GtkWidget *widget,
 			     gpointer data)
 {
-  GConfClient *client = gconf_client_get_default ();
-  gboolean fs = false;
-
-  fs = 
-    gconf_client_get_bool (client, 
-			   VIDEO_DISPLAY_KEY "fullscreen", 0);
-  gconf_client_set_bool (client, VIDEO_DISPLAY_KEY "fullscreen",
-			 !fs, NULL);
+  gconf_set_float (VIDEO_DISPLAY_KEY "zoom_factor", -1.0);
 }
 
 
@@ -177,12 +168,10 @@ radio_menu_changed (GtkWidget *widget,
 		    gpointer data)
 {
   GSList *group = NULL;
-  GConfClient *client = NULL;
 
   int group_last_pos = 0;
   int active = 0;
 
-  client = gconf_client_get_default ();
   group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (widget));
   group_last_pos = g_slist_length (group) - 1; /* If length 1, last pos is 0 */
 
@@ -199,7 +188,7 @@ radio_menu_changed (GtkWidget *widget,
       group = g_slist_next (group);
     }
 
-    gconf_client_set_int (client, (gchar *) data, group_last_pos - active, 0);
+    gconf_set_int ((gchar *) data, group_last_pos - active);
   }
 }
 
@@ -212,11 +201,7 @@ radio_menu_changed (GtkWidget *widget,
 static void 
 toggle_menu_changed (GtkWidget *widget, gpointer data)
 {
-  GConfClient *client = gconf_client_get_default ();
-
-  gconf_client_set_bool (client,
-			 (gchar *) data,
-			 GTK_CHECK_MENU_ITEM (widget)->active, NULL);
+  gconf_set_bool ((gchar *) data, GTK_CHECK_MENU_ITEM (widget)->active);
 }
 
 
@@ -227,15 +212,12 @@ gnomemeeting_init_menu (GtkAccelGroup *accel)
   GmWindow *gw = NULL;
   GmTextChat *chat = NULL;
 
-  GConfClient *client = NULL;
   GtkWidget *menubar = NULL;
 
   IncomingCallMode icm = AVAILABLE;
   ControlPanelSection cps = CLOSED;
   bool show_status_bar = false;
   bool show_chat_window = false;
-  
-  client = gconf_client_get_default ();
 
   chat = GnomeMeeting::Process ()->GetTextChat ();
   gw = GnomeMeeting::Process ()->GetMainWindow ();
@@ -244,13 +226,13 @@ gnomemeeting_init_menu (GtkAccelGroup *accel)
 
   /* Default values */
   icm = (IncomingCallMode) 
-    gconf_client_get_int (client, CALL_OPTIONS_KEY "incoming_call_mode", 0); 
+    gconf_get_int (CALL_OPTIONS_KEY "incoming_call_mode"); 
   cps = (ControlPanelSection)
-    gconf_client_get_int (client, USER_INTERFACE_KEY "main_window/control_panel_section", 0); 
+    gconf_get_int (USER_INTERFACE_KEY "main_window/control_panel_section"); 
   show_status_bar =
-    gconf_client_get_bool (client, USER_INTERFACE_KEY "main_window/show_status_bar", 0); 
+    gconf_get_bool (USER_INTERFACE_KEY "main_window/show_status_bar"); 
   show_chat_window =
-    gconf_client_get_bool (client, USER_INTERFACE_KEY "main_window/show_chat_window", 0); 
+    gconf_get_bool (USER_INTERFACE_KEY "main_window/show_chat_window"); 
   
   static MenuEntry gnomemeeting_menu [] =
     {
@@ -327,7 +309,7 @@ gnomemeeting_init_menu (GtkAccelGroup *accel)
       
       GTK_MENU_ENTRY("close", _("_Close"), _("Close the GnomeMeeting window"),
 		     GTK_STOCK_CLOSE, 'W', 
-		     GTK_SIGNAL_FUNC (gnomemeeting_component_view),
+		     GTK_SIGNAL_FUNC (show_window_cb),
 		     (gpointer) gm, TRUE),
 
       GTK_MENU_SEPARATOR,
@@ -342,7 +324,7 @@ gnomemeeting_init_menu (GtkAccelGroup *accel)
       GTK_MENU_ENTRY("configuration_druid", _("Configuration Druid"),
 		     _("Run the configuration druid"),
 		     NULL, 0, 
-		     GTK_SIGNAL_FUNC (gnomemeeting_component_view),
+		     GTK_SIGNAL_FUNC (show_window_cb),
 		     (gpointer) gw->druid_window, TRUE),
 #else
       GTK_MENU_ENTRY("configuration_druid", _("Configuration Druid"),
@@ -353,7 +335,7 @@ gnomemeeting_init_menu (GtkAccelGroup *accel)
 
       GTK_MENU_SEPARATOR,
 
-      GTK_MENU_ENTRY("preferences", _("_Preferences..."),
+      GTK_MENU_ENTRY("preferences", _("_Preferences"),
 		     _("Change your preferences"), 
 		     GTK_STOCK_PREFERENCES, 'P',
 		     GTK_SIGNAL_FUNC (show_window_cb),
@@ -407,7 +389,7 @@ gnomemeeting_init_menu (GtkAccelGroup *accel)
 
       GTK_MENU_SEPARATOR,
 
-      GTK_MENU_ENTRY("clear_text_chat", _("_Clear text chat"),
+      GTK_MENU_ENTRY("clear_text_chat", _("_Clear Text Chat"),
 		     _("Clear the text chat"), 
 		     GTK_STOCK_CLEAR, 'L',
 		     GTK_SIGNAL_FUNC (gnomemeeting_text_chat_clear),
@@ -478,11 +460,11 @@ gnomemeeting_init_menu (GtkAccelGroup *accel)
 
       GTK_MENU_SEPARATOR,
 
-      GTK_MENU_ENTRY("general_history", _("General History"),
+      GTK_MENU_ENTRY("log", _("General History"),
 		     _("View the operations history"),
 		     NULL, 0, 
 		     GTK_SIGNAL_FUNC (show_window_cb),
-		     (gpointer) gw->history_window, TRUE),
+		     (gpointer) gw->log_window, TRUE),
       GTK_MENU_ENTRY("calls_history", _("Calls History"),
 		     _("View the calls history"),
 		     GM_STOCK_CALLS_HISTORY, 'h',
@@ -500,13 +482,25 @@ gnomemeeting_init_menu (GtkAccelGroup *accel)
       GTK_MENU_NEW(_("_Help")),
 
 #ifndef DISABLE_GNOME
-      GTK_MENU_ENTRY("about", _("_About GnomeMeeting"),
+       GTK_MENU_ENTRY("help", _("_Contents"),
+                     _("Get help by reading the GnomeMeeting manual"),
+                     GTK_STOCK_HELP, GDK_F1, 
+                     GTK_SIGNAL_FUNC (help_cb), NULL, TRUE),
+#else
+       GTK_MENU_ENTRY("help", _("_Contents"),
+                     _("Get help by reading the GnomeMeeting manual"),
+                     GTK_STOCK_HELP, GDK_F1, 
+                     NULL, NULL, TRUE),
+#endif
+       
+#ifndef DISABLE_GNOME
+      GTK_MENU_ENTRY("about", _("_About"),
 		     _("View information about GnomeMeeting"),
 		     GNOME_STOCK_ABOUT, 0, 
 		     GTK_SIGNAL_FUNC (about_callback), (gpointer) gm,
 		     TRUE),
 #else
-      GTK_MENU_ENTRY("about", _("_About GnomeMeeting"),
+      GTK_MENU_ENTRY("about", _("_About"),
 		     _("View information about GnomeMeeting"),
 		     NULL, 'a', 
 		     GTK_SIGNAL_FUNC (about_callback), (gpointer) gm,
@@ -597,15 +591,12 @@ GtkWidget *
 gnomemeeting_tray_init_menu (GtkWidget *widget)
 {
   GtkWidget *popup_menu_widget = NULL;
-  GConfClient *client = NULL;
   IncomingCallMode icm = AVAILABLE;
   GmWindow *gw = NULL;
 
   
-  client = gconf_client_get_default ();
   gw = GnomeMeeting::Process ()->GetMainWindow ();
-  icm = (IncomingCallMode) 
-    gconf_client_get_int (client, CALL_OPTIONS_KEY "incoming_call_mode", 0); 
+  icm = (IncomingCallMode)gconf_get_int (CALL_OPTIONS_KEY "incoming_call_mode"); 
 
   static MenuEntry tray_menu [] =
     {
@@ -647,7 +638,7 @@ gnomemeeting_tray_init_menu (GtkWidget *widget)
       GTK_MENU_ENTRY("address_book", _("Address _Book"),
 		     _("Open the address book"),
 		     GM_STOCK_ADDRESSBOOK_16, 0,
-		     GTK_SIGNAL_FUNC (gnomemeeting_component_view),
+		     GTK_SIGNAL_FUNC (show_window_cb),
 		     (gpointer) gw->ldap_window, TRUE),
 
       GTK_MENU_SEPARATOR,
@@ -655,19 +646,19 @@ gnomemeeting_tray_init_menu (GtkWidget *widget)
       GTK_MENU_ENTRY("calls_history", _("Calls History"),
 		     _("View the calls history"),
 		     GM_STOCK_CALLS_HISTORY, 0, 
-		     GTK_SIGNAL_FUNC (gnomemeeting_component_view),
+		     GTK_SIGNAL_FUNC (show_window_cb),
 		     (gpointer) gw->calls_history_window, TRUE),
 
       GTK_MENU_SEPARATOR,
 
-      GTK_MENU_ENTRY("preferences", _("_Preferences..."),
+      GTK_MENU_ENTRY("preferences", _("_Preferences"),
 		     _("Change your preferences"),
 		     GTK_STOCK_PREFERENCES, 'P', 
-		     GTK_SIGNAL_FUNC (gnomemeeting_component_view),
+		     GTK_SIGNAL_FUNC (show_window_cb),
 		     (gpointer) gw->pref_window, TRUE),
 
       GTK_MENU_SEPARATOR,
-
+     
 #ifndef DISABLE_GNOME
       GTK_MENU_ENTRY("about", _("_About GnomeMeeting"),
 		     _("View information about GnomeMeeting"),
