@@ -1,6 +1,6 @@
 
 /* GnomeMeeting -- A Video-Conferencing application
- * Copyright (C) 2000-2003 Damien Sandras
+ * Copyright (C) 2000-2004 Damien Sandras
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -30,7 +30,7 @@
  *                         videograbber.cpp  -  description
  *                         --------------------------------
  *   begin                : Mon Feb 12 2001
- *   copyright            : (C) 2000-2003 by Damien Sandras
+ *   copyright            : (C) 2000-2004 by Damien Sandras
  *   description          : Video4Linux compliant functions to manipulate the 
  *                          webcam device.
  *
@@ -42,6 +42,7 @@
 #include "videograbber.h"
 #include "gnomemeeting.h"
 #include "misc.h"
+#include "tools.h"
 
 #include "dialog.h"
 #include "gconf_widgets_extensions.h"
@@ -120,9 +121,9 @@ GMVideoGrabber::Main ()
       video_channel->Read (video_buffer, height * width * 3);
       video_channel->Write (video_buffer, height * width * 3);    
     }
-    else
-      Current()->Sleep (50);
     var_mutex.Signal ();
+
+    Current()->Sleep (20);
   }
 
   VGClose ();
@@ -233,6 +234,18 @@ GMVideoGrabber::GetParameters (int *whiteness,
 }
 
 
+BOOL
+GMVideoGrabber::IsChannelOpen ()
+{
+  PWaitAndSignal m(var_mutex);
+
+  if (video_channel && video_channel->IsOpen ()) 
+    return TRUE;
+  
+  return FALSE;
+}
+
+
 void
 GMVideoGrabber::Lock ()
 {
@@ -301,7 +314,7 @@ GMVideoGrabber::VGOpen (void)
     if (!no_device_found) {
  
       gnomemeeting_threads_enter ();
-      gnomemeeting_log_insert (gw->history_text_view, _("Opening video device %s with plugin %s"), (const char *) input_device, (const char *) plugin);
+      gnomemeeting_log_insert (_("Opening video device %s with plugin %s"), (const char *) input_device, (const char *) plugin);
       gnomemeeting_threads_leave ();
 
       var_mutex.Wait ();
@@ -326,7 +339,7 @@ GMVideoGrabber::VGOpen (void)
       if (!error_code) {
 
 	gnomemeeting_threads_enter ();
-	gnomemeeting_log_insert (gw->history_text_view, _("Successfully opened video device %s, channel %d"), (const char *) input_device, channel);
+	gnomemeeting_log_insert (_("Successfully opened video device %s, channel %d"), (const char *) input_device, channel);
 	gnomemeeting_threads_leave ();
       }
       else {
@@ -340,8 +353,7 @@ GMVideoGrabber::VGOpen (void)
 
 	/* Translators: Do not translate MovingLogo and Picture */
 	tmp_msg = g_strdup (_("A moving GnomeMeeting logo will be transmitted during calls. Notice that you can always transmit a given image or the moving GnomeMeeting logo by choosing \"Picture\" as video plugin and \"MovingLogo\" or \"StaticPicture\" as device."));
-	gnomemeeting_log_insert (gw->history_text_view,
-				 _("Couldn't open the video device"));
+	gnomemeeting_log_insert (_("Couldn't open the video device"));
 	switch (error_code) {
 	  
 	case 1:
@@ -404,7 +416,7 @@ GMVideoGrabber::VGOpen (void)
 	grabber->SetFrameSizeConverter (width, height, FALSE);
 	
 	gnomemeeting_threads_enter ();
-	gnomemeeting_log_insert (gw->history_text_view, _("Opened the video device using the \"Picture\" video plugin"));
+	gnomemeeting_log_insert (_("Opened the video device using the \"Picture\" video plugin"));
 	gnomemeeting_threads_leave ();
       }
       var_mutex.Signal ();
